﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns="http://www.w3.org/1999/xhtml"
							  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
							  xmlns:msa="http://www.publictalksoftware.co.uk/msa">
	<!-- Output specification -->
	<xsl:output method="html" indent="yes" version="4.01"
	  doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"
	  doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"/>

	<!-- Parameters -->
	<xsl:param name="CSSFile1"></xsl:param>

	<xsl:variable name="EventsDatabase" select="document('MSA_SpecialEventsDatabase.xml')"/>
				  
	<xsl:template match="/">
		<html xmlns="http://www.w3.org/1999/xhtml">
			<xsl:choose>
				<xsl:when test="//Settings/ForeignGroupMode=1">
					<xsl:attribute name="lang">
						<xsl:value-of select="//Settings/ForeignGroupLanguageCode"/>
					</xsl:attribute>
					<xsl:attribute name="dir">
						<xsl:value-of select="//Settings/ForeignGroupDirection"/>
					</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="lang">
						<xsl:value-of select="//Settings/LanguageCode"/>
					</xsl:attribute>
					<xsl:attribute name="dir">
						<xsl:value-of select="//Settings/Direction"/>
					</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
			<head>
				<meta http-equiv="X-UA-Compatible" content="IE=edge" />
				<meta content="text/html; charset=utf-8" http-equiv="Content-Type" />
				<xsl:choose>
					<xsl:when test="$CSSFile1 !=''">
						<style type="text/css">
							<xsl:value-of select="$CSSFile1"/>
						</style>
					</xsl:when>
					<xsl:otherwise>
						<link rel="stylesheet" type="text/css" href="Workbook-S-140.css"/>
					</xsl:otherwise>
				</xsl:choose>
				<title>
					<xsl:value-of select="//Labels/Congregation"/>&#160;<xsl:value-of select="//Labels/Title" />
				</title>
			</head>
			<body>
				<div class="containerPage">
					<xsl:for-each select="MeetingWorkBook/Meeting">
						<div class="containerMeeting">
							<xsl:if test="@PageBreak=1">
								<xsl:attribute name="style">page-break-before: always</xsl:attribute>
							</xsl:if>
							<xsl:if test="@PageBreak=1 or position()=1">
								<xsl:call-template name="HEADING"/>
							</xsl:if>
							<xsl:if test="@BookmarkId">
								<a>
									<xsl:attribute name="name">
										<xsl:value-of select="concat('week', @BookmarkId)"/>
									</xsl:attribute>
									<![CDATA[ ]]>
								</a>
							</xsl:if>

							<!-- Search for Special Event -->
							<!-- Still need to handle FLG mode-->
							<xsl:variable name="event" select="$EventsDatabase/msa:SpecialEvents/msa:SpecialEvent[@Week = current()/Date/@ThisWeek]"/>

							<xsl:choose>
								
								<!-- Special Event -->
								<xsl:when test="$event">
									<xsl:choose>

										<!-- Simple Special Event -->
										<xsl:when test="$event/msa:MWBEventType = 'MWBSpecialEvent'">
											<!-- Event -->
											<table class="tableDATE" cellspacing="0" cellpadding="0">
												<xsl:call-template name="SetColumnWidths"/>
												<tr>
													<td class="cellBibleReadingFullRow" colspan="4">
														<xsl:value-of select="Date"/>
														<xsl:if test="WeeklyBibleReading != ''">
															<xsl:text> | </xsl:text>
															<xsl:value-of select="WeeklyBibleReading"/>
														</xsl:if>
													</td>
												</tr>
												<xsl:apply-templates select="$event">
													<xsl:with-param name="labelsDatabase" select="//Labels"/>
												</xsl:apply-templates>
											</table>
										</xsl:when>

										<!-- Bethel Speaker Service Talk -->
										<xsl:when test="$event/msa:MWBEventType = 'MWBBethelSpeakerServiceTalk'">
											<!-- Midweek Meeting -->
											<!--<xsl:apply-templates select="."/>-->
											<!-- Event -->
											<xsl:apply-templates select="$event" mode="BethelSpeakerOrMemorial">
												<xsl:with-param name="labelsDatabase" select="//Labels"/>
												<xsl:with-param name="use24HourFormat" select="//Settings/Use24HourFormat='1'"/>
												<xsl:with-param name="useStartTime" select="//Settings/UseStartTime='1'"/>
											</xsl:apply-templates>
											<!-- Weekend Meeting -->
											<xsl:call-template name="WEEK"/>
											<xsl:apply-templates select="./PUBLICTALK"/>
										</xsl:when>

										<!-- Memorial -->
										<xsl:when test="$event/msa:MWBEventType = 'MWBMemorial'">
											<xsl:choose>
												<xsl:when test="$event/msa:DateTime/msa:Date/@WeekendEvent='true'">
													<!-- Midweek Meeting -->
													<!--<xsl:apply-templates select="."/>-->
													<!-- Event -->
													<xsl:apply-templates select="$event" mode="BethelSpeakerOrMemorial">
														<xsl:with-param name="labelsDatabase" select="//Labels"/>
														<xsl:with-param name="use24HourFormat" select="//Settings/Use24HourFormat='1'"/>
														<xsl:with-param name="useStartTime" select="//Settings/UseStartTime='1'"/>
													</xsl:apply-templates>
												</xsl:when>
												<xsl:otherwise>
													<!-- Event -->
													<xsl:apply-templates select="$event" mode="BethelSpeakerOrMemorial">
														<xsl:with-param name="labelsDatabase" select="//Labels"/>
													</xsl:apply-templates>
													<!-- Weekend Meeting -->
													<xsl:call-template name="WEEK"/>
													<xsl:apply-templates select="./PUBLICTALK"/>
												</xsl:otherwise>
												
											</xsl:choose>
										</xsl:when>

										<!-- Circuit Assembly - by Videoconferencing (Live or Recorded) -->
										<xsl:when test="$event/msa:MWBEventType = 'MWBVideoconferenceAssembly'">
											<!-- Date Info -->
											<xsl:call-template name="VideoConferenceWeek">
												<xsl:with-param name="labelsDatabase" select="//Labels"/>
												<xsl:with-param name="liveEvent" select="$event/msa:Media/msa:VideoConferenceType ='Live'"/>
											</xsl:call-template>
											
											<!-- Watchtower Study (Recorded) -->
											<xsl:if test="$event/msa:Media/msa:VideoConferenceType='Recorded'">
												<table class="tableWeekend">
													<colgroup>
														<col class ="columnTime"/>
														<col class ="columnPublicTalk"/>
														<col class ="columnName"/>
													</colgroup>
													<xsl:apply-templates select="PUBLICTALK/Assignments" mode="AudioVisualTeam"/>
													<xsl:apply-templates select="PUBLICTALK/Assignments/WatchtowerStudy" mode="SpecialEvent"/>
												</table>
											</xsl:if>

											<!-- Event -->
											<xsl:apply-templates select="$event" mode="VideoConferenceEvent"/>
										</xsl:when>

										<xsl:when test="$event/msa:MWBEventType = 'MWBVideoconferenceConvention'">
											<!-- Midweek Meeting -->
											<!--<xsl:apply-templates select="."/>-->

											<!-- Watchtower Study -->
											<xsl:call-template name="WEEK"/>
											<table class="tableWeekend">
												<colgroup>
													<col class ="columnTime"/>
													<col class ="columnPublicTalk"/>
													<col class ="columnName"/>
												</colgroup>
												<xsl:apply-templates select="PUBLICTALK/Assignments" mode="AudioVisualTeam"/>
												<xsl:apply-templates select="PUBLICTALK/Assignments/WatchtowerStudy" mode="SpecialEvent"/>
											</table>

											<!-- Event -->
											<xsl:apply-templates select="$event" mode="VideoConferenceEvent"/>
										</xsl:when>

										<!-- Circuit Overseer Visit -->
										<xsl:when test="$event/msa:MWBEventType = 'MWBCircuitOverseerMeeting'">
											<!-- Midweek Meeting -->
											<!--<xsl:apply-templates select="."/>-->
											<!-- Weekend Meeting, with Circuit Overseer Service Talk -->
											<xsl:call-template name="WEEK"/>
											<xsl:apply-templates select="./PUBLICTALK"/>
										</xsl:when>

										<!-- Normal Week -->
										<xsl:otherwise>
											<!-- Midweek Meeting -->
											<!--<xsl:apply-templates select="."/>-->
											<!-- Weekend Meeting -->
											<xsl:call-template name="WEEK"/>
											<xsl:apply-templates select="./PUBLICTALK"/>
										</xsl:otherwise>

									</xsl:choose>
								</xsl:when>
								
								<!-- Normal Week -->
								<xsl:otherwise>
									<!-- Midweek Meeting -->
									<!--<xsl:apply-templates select="."/>-->
									<!-- Weekend Meeting -->
									<xsl:call-template name="WEEK"/>
									<xsl:apply-templates select="./PUBLICTALK"/>
								</xsl:otherwise>
								
							</xsl:choose>
						</div>
					</xsl:for-each>
				</div>
			</body>
		</html>
	</xsl:template>

	<!-- Midweek Meeting -->
	<xsl:template match="Meeting">
		<xsl:call-template name="WEEK"/>
		<xsl:apply-templates select="TFGW"/>
		<xsl:apply-templates select="AYFM"/>
		<xsl:apply-templates select="LAC"/>
	</xsl:template>

	<!-- Weekend Meeting -->
	<xsl:template match="PUBLICTALK">
		<table class="tableWeekend">
			<colgroup>
				<col class ="columnTime"/>
				<col class ="columnPublicTalk"/>
				<col class ="columnName"/>
			</colgroup>
			<tr>
				<td class ="cellWEEKEND" colspan="2">
					<div class="textWEEKEND">
						<xsl:value-of select="//Labels/PTS_WeekendMeeting"/>
					</div>
					<div class="floatRight textHeadingLabel">
						<xsl:value-of select="//Labels/PTS_Chairman"/>:
					</div>
				</td>
				<td class="cellName">
					<xsl:value-of select="Assignments/Chairman"/>
				</td>
			</tr>
			<xsl:apply-templates select="Assignments" mode="AudioVisualTeam"/>
			<xsl:apply-templates select="Assignments/PrayerOpen" mode="WeekendMeeting"/>
			<xsl:apply-templates select="HomeTalk"/>
			<xsl:apply-templates select="AwayTalk"/>
			<xsl:apply-templates select="Assignments"/>
			<xsl:apply-templates select="Assignments/PrayerClose" mode="WeekendMeeting"/>
		</table>
	</xsl:template>
	
	<!-- Weekend Meeting - Limited to Watchtower Study -->
	<xsl:template match="PUBLICTALK" mode="WatchtowerStudyOnly">
		<tr>
			<td style="padding-left: 1mm;" colspan="3">
				<div class="WTHeading">
					<xsl:value-of select="//Labels/PTS_WTStudy"/>
				</div>
			</td>
		</tr>

		<!-- Optional: Display the opening song for the Watchtower Study -->
		<!-- Comment this line out if you do not want to display it -->
		<xsl:apply-templates select="../../SongInfo/SongMiddle" mode="SpecialEvent" />
		<tr>
			<xsl:apply-templates select="Time" mode="Start"/>
			<td class="cellWEEKENDText">
				<div class="floatRight">
					<xsl:value-of select="//Labels/PTS_WTConductor"/>
					<xsl:text>:</xsl:text>
				</div>
				<span class="textPTSValue">
					<xsl:value-of select="Theme"/>
				</span>
			</td>
			<td class="cellName">
				<xsl:value-of select="../Conductor"/>
			</td>
		</tr>
		<!-- Optional: Display the closing song for the Watchtower Study -->
		<!-- Comment this line out if you do not want to display it -->
		<xsl:apply-templates select="../../SongInfo/SongEnd" mode="SpecialEvent" />
	</xsl:template>

	<!-- Simple Special Event -->
	<xsl:template match="msa:SpecialEvent">
		<xsl:param name="labelsDatabase"/>
		<tr>
			<td class="textSpecialEvent" colspan="4">
				<xsl:value-of select="msa:Event"/>
				<xsl:text> [</xsl:text>
				<xsl:value-of select="msa:DateTime/msa:Date"/>
				<xsl:text>]</xsl:text>
			</td>
		</tr>
		<xsl:if test="normalize-space(msa:Location) != ''">
			<tr>
				<td class="textSpecialEventLocation" colspan="4">
					<xsl:value-of select="msa:Location"/>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>

	<!-- Bethel Speaker Visit or Memorial -->
	<xsl:template match="msa:SpecialEvent" mode="BethelSpeakerOrMemorial">
		<xsl:param name="labelsDatabase"/>
		<xsl:param name="use24HourFormat"/>
		<xsl:param name="useStartTime"/>
		<table class="table-event">
			<colgroup>
				<col class="columnTime"/>
				<col class="columnPublicTalk"/>
				<col class="columnName"/>
			</colgroup>
			<!-- Row: Heading -->
			<tr>
				<td class="cell-event" colspan="3">
					<div class="textMemorialHeading">
						<xsl:value-of select="msa:Event"/>
					</div>
				</td>
			</tr>
			<!-- Date and Chairman -->
			<tr>
				<td class="cell-event" colspan="2">
					<div class="event-date">
						<xsl:value-of select="msa:DateTime/msa:Date/@DayFull"/>
						<xsl:text> </xsl:text>
						<xsl:value-of select="msa:DateTime/msa:Date/@Day"/>
						<xsl:text> | </xsl:text>
						<xsl:value-of select="msa:DateTime/msa:Date/@MonthFull"/>
					</div>
					<div class="floatRight textHeadingLabel">
						<xsl:value-of select="$labelsDatabase/PTS_Chairman"/>
					</div>
				</td>
				<td class="cellName">
					<xsl:value-of select="msa:Assignments/msa:Chairman"/>
				</td>
			</tr>

			<!-- Row: Audio Visual Team -->
			<xsl:choose>
				<xsl:when test="../msa:MWBEventType = 'MWBBethelSpeakerServiceTalk'">
					<xsl:apply-templates select="msa:Duties" mode="BethelSpeaker">
						<xsl:with-param name="labelsDatabase" select="$labelsDatabase"/>
					</xsl:apply-templates>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="msa:Duties">
						<xsl:with-param name="labelsDatabase" select="$labelsDatabase"/>
					</xsl:apply-templates>
				</xsl:otherwise>
			</xsl:choose>
			
			<!-- Row: Opening Song and Prayer -->
			<tr>
				<!-- Song -->
				<xsl:apply-templates select="msa:Songs/msa:SongOpen" mode="Memorial">
					<xsl:with-param name="labelsDatabase" select="$labelsDatabase"/>
					<xsl:with-param name="use24HourFormat" select="$use24HourFormat"/>
					<xsl:with-param name="useStartTime" select="$useStartTime"/>
				</xsl:apply-templates>
				<!-- Prayer -->
				<xsl:apply-templates select="msa:Assignments/msa:PrayerOpen" />
			</tr>
			<!-- Row: Theme and Speaker -->
			<tr>
				<!-- Time -->
				<xsl:apply-templates select="msa:Talk/msa:TimeInfo">
					<xsl:with-param name="use24HourFormat" select="$use24HourFormat"/>
					<xsl:with-param name="useStartTime" select="$useStartTime"/>
				</xsl:apply-templates>
				<!-- Theme -->
				<td class="cellTheme">
					<span class="bullet-event">
						<xsl:text>&#8226;</xsl:text>
					</span>
					<span class="textPTSLabel">
						<xsl:value-of select="$labelsDatabase/PTS_Theme"/>:
					</span>
					<xsl:text> </xsl:text>
					<span class="textPTSValue">
						<xsl:value-of select="msa:Talk/msa:Theme"/>
					</span>
					<div class="floatRight">
						<xsl:value-of select="$labelsDatabase/PTS_Speaker"/>:
					</div>
				</td>
				<!-- Speaker -->
				<td class="cellName">
					<xsl:value-of select="msa:Talk/msa:Speaker"/>
				</td>
			</tr>
			<!-- Row: Closing Song and Prayer -->
			<tr>
				<!-- Song -->
				<xsl:apply-templates select="msa:Songs/msa:SongEnd" mode="Memorial">
					<xsl:with-param name="labelsDatabase" select="$labelsDatabase"/>
					<xsl:with-param name="timeInfo" select="msa:DateTime/msa:Time/msa:SongEndTimeInfo"/>
					<xsl:with-param name="use24HourFormat" select="$use24HourFormat"/>
					<xsl:with-param name="useStartTime" select="$useStartTime"/>
				</xsl:apply-templates>
				<!-- Prayer -->
				<xsl:apply-templates select="msa:Assignments/msa:PrayerClose" />
			</tr>
			<xsl:if test="msa:MWBEventType != 'MWBBethelSpeakerServiceTalk'">
				<!-- Location, Image and Notes -->
				<tr>
					<td colspan="3" class="event-container">
						<!-- Location -->
						<p class="event-location">
							<xsl:value-of select="msa:Location"/>
						</p>

						<!-- Notes and Media -->
						<xsl:apply-templates select="msa:Media"/>
					</td>
				</tr>
			</xsl:if>
		</table>
	</xsl:template>

	<!-- Videoconference Media information -->
	<xsl:template match="msa:SpecialEvent" mode="VideoConferenceEvent">
		<div class="event-container">
			<!-- Info Before -->
			<p class="event-textbefore">
				<xsl:value-of select="msa:Media/msa:TextBeforeImage" disable-output-escaping="yes"/>
			</p>

			<!-- Media -->
			<img class="event-image">
				<xsl:attribute name="src">
					<xsl:value-of select="msa:Media/msa:ImagePath"/>
				</xsl:attribute>
				<xsl:attribute name="width">
					<xsl:value-of select="msa:Media/msa:ImageWidthPercent"/>
					<xsl:text>%</xsl:text>
				</xsl:attribute>
				<xsl:attribute name="alt">
					<xsl:text>Event Image</xsl:text>
				</xsl:attribute>
			</img>

			<!-- Event -->
			<p class="event-event">
				<xsl:value-of select="msa:Event"/>
			</p>

			<!-- Info After -->
			<p class="event-textafter">
				<xsl:value-of select="msa:Media/msa:TextAfterImage" disable-output-escaping="yes"/>
			</p>
		</div>
	</xsl:template>

	<!-- Bethel Visit / Memorial Media information -->
	<xsl:template match="msa:Media">
		<!-- Info Before -->
		<p class="event-textbefore">
			<xsl:value-of select="msa:TextBeforeImage" disable-output-escaping="yes"/>
		</p>
		
		<!-- Media -->
		<img class="event-image">
			<xsl:attribute name="src">
				<xsl:value-of select="msa:ImagePath"/>
			</xsl:attribute>
			<xsl:attribute name="width">
				<xsl:value-of select="msa:ImageWidthPercent"/>
				<xsl:text>%</xsl:text>
			</xsl:attribute>
			<xsl:attribute name="alt">
				<xsl:text>Event Image</xsl:text>
			</xsl:attribute>
		</img>
		
		<!-- Info After -->
		<p class="event-textafter">
			<xsl:value-of select="msa:TextAfterImage" disable-output-escaping="yes"/>
		</p>
	</xsl:template>

	<!-- Row: Audio / Visual Team -->
	<xsl:template match="msa:Duties">
		<xsl:param name="labelsDatabase"/>
		<xsl:if test="msa:Video != '' and msa:Audio != '' and msa:Zoom != ''">
			<tr>
				<td colspan="2">
					<div class="floatRight">
						<xsl:value-of select="$labelsDatabase/VideoConferenceHost"/>
						<br/>
						<xsl:value-of select="$labelsDatabase/VideoConferenceCohost"/>
						<br/>
						<xsl:value-of select="$labelsDatabase/ZoomAttendant"/>
					</div>
				</td>
				<td class="cellName">
					<xsl:apply-templates select="msa:Video"/>
					<br/>
					<xsl:apply-templates select="msa:Audio"/>
					<br/>
					<xsl:apply-templates select="msa:Zoom"/>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>


	<!-- Row: Audio / Visual Team (normal meeting) -->
	<xsl:template match="Assignments | Meeting" mode="AudioVisualTeam">
		<xsl:if test="VideoConferenceHost != '' and VideoConferenceCohost != ''">
			<tr>
				<td class ="cellWEEKEND">
					<xsl:attribute name="colspan">
						<xsl:choose>
							<xsl:when test="self::Assignments">2</xsl:when>
							<xsl:otherwise>3</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<div class="floatRight">
						<xsl:value-of select="//Labels/VideoConferenceHost"/>
						<br/>
						<xsl:value-of select="//Labels/VideoConferenceCohost"/>
						<br/>
						<xsl:value-of select="//Labels/ZoomAttendant"/>
					</div>
				</td>
				<td class="cellName">
					<xsl:apply-templates select="VideoConferenceHost"/>
					<br/>
					<xsl:apply-templates select="VideoConferenceCohost"/>
					<br/>
					<xsl:apply-templates select="ZoomAttendant"/>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>

	<!-- Row: Audio / Visual Team (Bethel Speaker Visit) -->
	<xsl:template match="msa:Duties" mode="BethelSpeaker">
		<xsl:param name="labelsDatabase"/>
		<xsl:if test="msa:Video != '' and msa:Audio != ''">
			<tr>
				<td colspan="2">
					<div class="floatRight">
						<xsl:value-of select="$labelsDatabase/VideoConferenceHost"/>
						<br/>
						<xsl:value-of select="$labelsDatabase/VideoConferenceCohost"/>
					</div>
				</td>
				<td class="cellName">
					<xsl:apply-templates select="msa:Video"/>
					<br/>
					<xsl:apply-templates select="msa:Audio"/>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>
	
	<!-- Song Information -->
	<xsl:template match="msa:SongOpen | msa:SongEnd" mode="Memorial">
		<xsl:param name="labelsDatabase"/>
		<xsl:param name="use24HourFormat"/>
		<xsl:param name="useStartTime"/>

		<!-- Time -->
		<xsl:apply-templates select="msa:TimeInfo">
			<xsl:with-param name="use24HourFormat" select="$use24HourFormat"/>
			<xsl:with-param name="useStartTime" select="$useStartTime"/>
		</xsl:apply-templates>
		<!-- Song -->
		<td class="cellTheme">
			<xsl:if test=". != 0">
				<span class="bulletMI">
					<xsl:text>&#8226;</xsl:text>
				</span>
				<span class="textSongLabel">
					<xsl:value-of select="$labelsDatabase/Song"/>
				</span>
				<span class="textSongNumber">
					<xsl:value-of select="@Number"/>
				</span>
				<span class="textSongTitle">
					<xsl:value-of select="msa:Title"/>
				</span>
			</xsl:if>
			<div class="floatRight">
				<xsl:value-of select="$labelsDatabase/Prayer"/>
			</div>
		</td>
	</xsl:template>

	<!-- Start or End Time -->
	<xsl:template match="msa:TimeInfo">
		<xsl:param name="use24HourFormat"/>
		<xsl:param name="useStartTime"/>
		<td class="cellTime">
			<xsl:choose>
				<xsl:when test="$use24HourFormat">
					<xsl:choose>
						<xsl:when test="$useStartTime">
							<xsl:value-of select="@StartTime24"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="@EndTime24"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="$useStartTime">
							<xsl:value-of select="@StartTime12"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="@EndTime12"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:otherwise>
			</xsl:choose>
		</td>
	</xsl:template>
	
	<!-- Date Info etc. -->
	<xsl:template name="WEEK">
		<table class="tableDATE" cellspacing="0" cellpadding="0">
			<xsl:call-template name="SetColumnWidths"/>
			<tr>
				<td class="cellBibleReading" colspan="4">
					<xsl:apply-templates select="PUBLICTALK/MeetingDate" mode="Custom"/>
				</td>
			</tr>
			<xsl:apply-templates select="Note"/>
		</table>
	</xsl:template>
	
	<xsl:template match="MeetingDate" mode="Custom">
		<xsl:value-of select="@DayFull"/>
		<xsl:text>, </xsl:text>
		<xsl:value-of select="@Day"/>
		<xsl:text> </xsl:text>
		<xsl:value-of select="@MonthFull"/>
	</xsl:template>	

	<!-- Displays Date info etc. for a Videoconference Event -->
	<xsl:template name="VideoConferenceWeek">
		<xsl:param name="labelsDatabase"/>
		<xsl:param name="liveEvent"/>

		<table class="tableDATE">
			<xsl:call-template name="SetColumnWidths"/>
			<xsl:choose>
				<xsl:when test="$liveEvent">
					<tr>
						<td class="cellBibleReadingFullRow" colspan="4">
							<xsl:value-of select="Date"/>
							<xsl:if test="WeeklyBibleReading != ''">
								<xsl:text> | </xsl:text>
								<xsl:value-of select="WeeklyBibleReading"/>
							</xsl:if>
						</td>
					</tr>
				</xsl:when>
				<xsl:otherwise>
					<tr>
						<!-- Use cellBibleReadingFullRow and 4 if you don't want to include the Chairman -->
						<td class="cellBibleReading" colspan="3">
							<!-- Remove this div if you don't want the Chairman label -->
							<div class="floatRight">
								<xsl:value-of select="$labelsDatabase/Chairman"/>
							</div>
							<xsl:value-of select="Date"/>
							<xsl:if test="WeeklyBibleReading != ''">
								<xsl:text> | </xsl:text>
								<xsl:value-of select="WeeklyBibleReading"/>
							</xsl:if>
						</td>
						<!-- Remove this td if you don't want to display the Chairman name -->
						<td class="cellName">
							<xsl:choose>
								<xsl:when test="Chairman/@Duplicate=1">
									<span class="textDuplicate">
										<xsl:value-of select="PUBLICTALK/Assignments/Chairman"/>
									</span>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="PUBLICTALK/Assignments/Chairman"/>
								</xsl:otherwise>
							</xsl:choose>
						</td>
					</tr>
				</xsl:otherwise>
			</xsl:choose>
		</table>
	</xsl:template>

	<!--Displays the notes (if any)-->
	<xsl:template match="Note">
		<xsl:if test="normalize-space(.) != ''">
			<tr>
				<td class="cellNotes" colspan="4">
					<xsl:value-of select="//Labels/Note"/>:&#160;<xsl:value-of select="."/>
				</td>
			</tr>
		</xsl:if>
	</xsl:template>

	<!--Displays heading with a nice double underline-->
	<xsl:template name="HEADING">
		<div class="borderHEADINGOuter">
			<div class="borderHEADINGInner">
				<table class="tableHEADING">
					<tr>
						<td class="textCongregation">
							<xsl:value-of select="//Labels/Congregation"/>
						</td>
						<td class="textTitle">
							<xsl:value-of select="//Labels/Title"/>
						</td>
					</tr>
				</table>
			</div>
		</div>
	</xsl:template>

	<xsl:template match="Time">
		<td class="cellTime">
			<xsl:call-template name="DisplayTime"/>
		</td>
	</xsl:template>

	<xsl:template name="DisplayTime">
		<xsl:choose>
			<xsl:when test="//Settings/Use24HourFormat='1'">
				<xsl:choose>
					<xsl:when test="//Settings/UseStartTime='1'">
						<xsl:value-of select="@StartTime24"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="@EndTime24"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="//Settings/UseStartTime='1'">
						<xsl:value-of select="@StartTime12"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="@EndTime12"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="DisplayTimeEx">
		<xsl:param name="time-node"/>
		<xsl:choose>
			<xsl:when test="//Settings/Use24HourFormat='1'">
				<xsl:choose>
					<xsl:when test="//Settings/UseStartTime">
						<xsl:value-of select="$time-node/@StartTime24"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$time-node/@EndTime24"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="//Settings/UseStartTime='1'">
						<xsl:value-of select="$time-node/@StartTime12"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$time-node/@EndTime12"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>	

	<!--Display the end time (using 24 hour format)-->
	<xsl:template match="Time" mode="End">
		<td class="cellTime">
			<xsl:value-of select="@EndTime24"/>
		</td>
	</xsl:template>

	<!--Display the start time (using 24 hour format)-->
	<xsl:template match="Time" mode="Start">
		<td class="cellTime">
			<xsl:value-of select="@StartTime24"/>
		</td>
	</xsl:template>

	<!--Displays the duration of the item in minutes-->
	<xsl:template match="Time" mode="Duration">
		<span class="textDuration">
			(<xsl:value-of select="."/>)
		</span>
	</xsl:template>

	<!--Display the name of the brother assigned-->
	<xsl:template match="Name | PrayerOpen | PrayerEnd | msa:PrayerOpen | msa:PrayerClose">
		<td class="cellName">
			<xsl:choose>
				<xsl:when test="@Duplicate=1">
					<span class="textDuplicate">
						<xsl:value-of select="."/>
					</span>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="."/>
				</xsl:otherwise>
			</xsl:choose>
		</td>
	</xsl:template>

	<!-- Display the Host / Co-Host / Zoom Attendant -->
	<xsl:template match="VideoConferenceHost | VideoConferenceCohost | ZoomAttendant | msa:Video | msa:Audio | msa:Zoom">
		<xsl:param name="NameToHighlight"/>
		<xsl:choose>
			<xsl:when test="@Duplicate=1">
				<span class="textDuplicate">
					<xsl:value-of select="."/>
				</span>
			</xsl:when>
			<xsl:when test=".=$NameToHighlight">
				<span class="textHighlight">
					<xsl:value-of select="."/>&#160;
				</span>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="."/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!--Displays the theme for the assignment-->
	<xsl:template match="Theme">
		<span class="textTheme">
			<xsl:value-of select="." disable-output-escaping="yes"/>
		</span>
	</xsl:template>

	<!--Displays the chairman label-->
	<xsl:template name="Chairman">
		<td class="cellName">
			<!--Trims the " :" from the end of the chairman label-->
			<xsl:value-of select="normalize-space(translate(//Labels/Chairman,':',''))"/>
		</td>
	</xsl:template>

	<xsl:template match="Method">
		<span class="textMethod">
			<xsl:value-of select="." disable-output-escaping="yes"/>
		</span>
	</xsl:template>

	<!--Treasures From God's Word-->
	<xsl:template match="TFGW">
		<table class="tableTFGW" cellspacing="0" cellpadding="0">
			<xsl:call-template name="SetColumnWidths"/>

			<xsl:call-template name="SectionHeading">
				<xsl:with-param name="strSection">TFGW</xsl:with-param>
				<xsl:with-param name="iSpanColumns">3</xsl:with-param>
			</xsl:call-template>

			<xsl:apply-templates select="TFGWItem">
				<xsl:with-param name="iSpanCols">
					<xsl:value-of select="@NumberClasses"/>
				</xsl:with-param>
			</xsl:apply-templates>
			<xsl:apply-templates select="BibleReadingItem"/>
		</table>
	</xsl:template>
	
	<xsl:template match="@Index">
		<span style="font-size: 10pt;">
			<xsl:value-of select="."/>
			<xsl:text>. </xsl:text>
		</span>
	</xsl:template>

	<!--Bible talk and Digging for Spiritual Gems-->
	<xsl:template match="TFGWItem">
		<xsl:param name="iSpanCols"/>
		<tr>
			<xsl:apply-templates select="Time"/>
			<td colspan="{$iSpanCols+1}">
				<xsl:apply-templates select="@Index"/>
				<!--<span class="bulletTFGW">&#8226;</span>-->
				<xsl:apply-templates select="Theme"/>
				<xsl:apply-templates select="Time" mode="Duration"/>
				<xsl:apply-templates select="Method"/>
			</td>
			<xsl:apply-templates select="Name"/>
		</tr>
	</xsl:template>

	<!--Displays all of the bible reading students for each class-->
	<xsl:template match="BibleReadingItem">
		<tr>
			<xsl:apply-templates select="Time"/>
			<td class="cellTheme">
				<xsl:apply-templates select="@Index"/>
				<!--<span class="bulletTFGW">&#8226;</span>-->
				<span class="textTheme">
					<xsl:value-of select="Type"/>
				</span>
				<xsl:apply-templates select="Time" mode="Duration"/>
				<xsl:apply-templates select="Material"/>
			</td>
			<td class="cellPosition">
				<xsl:value-of select="//Labels/Student"/>
			</td>
			<xsl:for-each select="Readers/Reader">
				<td class="cellName">
					<xsl:choose>
						<xsl:when test="@Duplicate=1">
							<span class="textDuplicate">
								<xsl:value-of select="."/>
							</span>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="."/>
						</xsl:otherwise>
					</xsl:choose>
				</td>
			</xsl:for-each>
		</tr>
	</xsl:template>

	<!-- Display the study number reference -->
	<xsl:template match="@StudyPointReference">
		<span class="textStudyNumberReference">
			<xsl:text> </xsl:text>
			<xsl:value-of select="."/>
		</span>
	</xsl:template>

	<!--Apply Yourself To The Field Ministry-->
	<xsl:template match="AYFM">
		<table class="tableAYFM" cellspacing="0" cellpadding="0">
			<xsl:call-template name="SetColumnWidths"/>

			<xsl:call-template name="SectionHeading">
				<xsl:with-param name="strSection">AYFM</xsl:with-param>
				<xsl:with-param name="iSpanColumns">3</xsl:with-param>
			</xsl:call-template>

			<xsl:apply-templates select="Teaching" />
			<xsl:apply-templates select="StudentItem"/>
		</table>
	</xsl:template>

	<!-- Teaching assigning - 10 minute talk -->
	<xsl:template match="Teaching">
		<tr>
			<xsl:apply-templates select="Time"/>
			<td class="cellTheme" colspan="2">
				<xsl:apply-templates select="@Index"/>
				<!--<span class="bulletAYFM">&#8226;</span>-->
				<span class="textTheme">
					<xsl:value-of select="Type"/>
				</span>
				<xsl:apply-templates select="Theme"/>
				<xsl:apply-templates select="Time" mode="Duration"/>
				<xsl:apply-templates select="SourceMaterial"/>
			</td>
			<xsl:apply-templates select="Names/Name"/>
		</tr>
	</xsl:template>

	<!--Displays all the information for a student item.
  This includes all the students from each class.-->
	<xsl:template match="StudentItem">
		<tr>
			<xsl:apply-templates select="Time"/>
			<td class="cellTheme">
				<xsl:apply-templates select="@Index"/>
				<!--<span class="bulletAYFM">&#8226;</span>-->
				<span class="textTheme">
					<xsl:value-of select="Type"/>
				</span>
				<xsl:apply-templates select="Time" mode="Duration"/>
				<xsl:choose>
					<xsl:when test="@IsSampleVideo=1">
						<xsl:apply-templates select="Material" mode="NoStudyPoint"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="Material"/>
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<td class="cellPosition">
				<xsl:choose>
					<xsl:when test="@IsSampleVideo=1">
						<!--We need an empty cell-->
						<xsl:text> </xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="//Labels/Student"/>
						<xsl:if test="@IsTalk=0">
							<br/>
							<xsl:value-of select="//Labels/Assistant"/>
						</xsl:if>
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<xsl:apply-templates select="Students"/>
		</tr>
	</xsl:template>

	<xsl:template match="Material | SourceMaterial | StudyPointDescription">
		<span class="textMaterial">
			<xsl:value-of select="." disable-output-escaping="yes"/>
			<!-- Display the study point in brackets (if it exists) -->
			<xsl:apply-templates select="@StudyPointReference"/>
		</span>
	</xsl:template>

	<xsl:template match="Material" mode="NoStudyPoint">
		<span class="textMaterial">
			<xsl:value-of select="." disable-output-escaping="yes"/>
		</span>
	</xsl:template>

	<!--Displays the student and assistant for the current student item-->
	<xsl:template match="Students">
		<td class="cellName">
			<xsl:choose>
				<xsl:when test="../@IsSampleVideo=1">
					<xsl:choose>
						<xsl:when test="@ChairmanHandleSampleVideo=0">
							<xsl:value-of select="//Labels/Counsellor"/>
						</xsl:when>
						<xsl:otherwise>
							<!--Trims the " :" from the end of the chairman label-->
							<xsl:value-of select="normalize-space(translate(//Labels/Chairman,':',''))"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:choose>
						<xsl:when test="Student/@Duplicate=1">
							<span class="textDuplicate">
								<xsl:value-of select="Student"/>
							</span>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="Student"/>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:if test="../@IsTalk=0">
						<br/>
						<xsl:choose>
							<xsl:when test="Assistant/@Duplicate=1">
								<span class="textDuplicate">
									<xsl:value-of select="Assistant"/>
								</span>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="Assistant"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:if>
				</xsl:otherwise>
			</xsl:choose>
		</td>
	</xsl:template>

	<!--Define the column widths for the schedule-->
	<xsl:template name="SetColumnWidths">
		<!--The widths in the column classes will add up to 100%-->
		<xsl:choose>
			<xsl:when test="not(@NumberClasses) or @NumberClasses=1 or self::Meeting">
				<colgroup>
					<col class="columnTime"/>
					<col class="columnTheme1Class"/>
					<col class="columnPosition"/>
					<col class="columnName"/>
				</colgroup>
			</xsl:when>
			<xsl:when test="@NumberClasses=2">
				<colgroup>
					<col class="columnTime"/>
					<col class="columnTheme2Class"/>
					<col class="columnPosition"/>
					<col class="columnName"/>
					<col class="columnName"/>
				</colgroup>
			</xsl:when>
			<xsl:when test="@NumberClasses=3">
				<colgroup>
					<col class="columnTime"/>
					<col class="columnTheme3Class"/>
					<col class="columnPosition"/>
					<col class="columnName"/>
					<col class="columnName"/>
					<col class="columnName"/>
				</colgroup>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<!--Living As Christians-->
	<xsl:template match="LAC">
		<table class="tableLAC" cellspacing="0" cellpadding="0">
			<xsl:call-template name="SetColumnWidths"/>

			<xsl:call-template name="SectionHeading">
				<xsl:with-param name="strSection">LAC</xsl:with-param>
				<xsl:with-param name="iSpanColumns">4</xsl:with-param>
			</xsl:call-template>

			<tr>
				<xsl:apply-templates select="SongMiddle" />
			</tr>
			<xsl:apply-templates select="LACItem" />

			<xsl:choose>
				<xsl:when test="@CircuitVisit=0  or @CircuitVisitGroup=1">
					<xsl:apply-templates select="CongregationBibleStudy" />
					<xsl:apply-templates select="ClosingComments"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="ClosingComments"/>
					<xsl:apply-templates select="CircuitVisit/LACItem"/>
				</xsl:otherwise>
			</xsl:choose>

			<tr>
				<xsl:apply-templates select="SongEnd"/>
				<xsl:apply-templates select="PrayerEnd" />
			</tr>
		</table>
	</xsl:template>

	<xsl:template name="SectionHeading">
		<xsl:param name="strSection"/>
		<xsl:param name="iSpanColumns"/>
		<tr>
			<td class="cell{$strSection}" colspan="{$iSpanColumns}">
				<div class="text{$strSection}">
					<xsl:value-of select="//Labels/*[name() = $strSection]"/>
				</div>
			</td>
			<xsl:if test="@NumberClasses = 3">
				<td class="cellClass">
					<xsl:value-of select="//Labels/AuxClass1"/>
				</td>
				<td class="cellClass">
					<xsl:value-of select="//Labels/AuxClass2"/>
				</td>
			</xsl:if>
			<xsl:if test="@NumberClasses = 2">
				<td class="cellClass">
					<xsl:value-of select="//Labels/AuxClass"/>
				</td>
			</xsl:if>
			<xsl:if test="@NumberClasses &gt;= 1">
				<td class="cellClass">
					<xsl:value-of select ="//Labels/MainHall"/>
				</td>
			</xsl:if>
		</tr>
	</xsl:template>

	<!--Living As Christians - Item-->
	<xsl:template match="LACItem">
		<tr>
			<xsl:apply-templates select="Time"/>
			<td class="cellTheme" colspan="2">
				<xsl:apply-templates select="@Index"/>
				<!--<span class="bulletLAC">&#8226;</span>-->
				<xsl:apply-templates select="Theme"/>
				<xsl:apply-templates select="Time" mode="Duration"/>
				<xsl:apply-templates select="Method"/>
			</td>
			<xsl:apply-templates select="Name"/>
		</tr>
	</xsl:template>

	<!--Displays the Congregation Bible Study information-->
	<xsl:template match="CongregationBibleStudy">
		<tr>
			<xsl:apply-templates select="Time"/>
			<td class="cellTheme">
				<xsl:apply-templates select="@Index"/>
				<!--<span class="bulletLAC">&#8226;</span>-->
				<span class="textTheme">
					<xsl:value-of select="//Labels/CBS"/>
				</span>
				<xsl:apply-templates select="Time" mode="Duration"/>
				<xsl:apply-templates select="SourceMaterial" />
			</td>
			<td class="cellPosition">
				<xsl:value-of select="//Labels/Conductor"/>
				<br/>
				<xsl:value-of select="//Labels/Reader"/>
			</td>
			<td class="cellName">
				<xsl:choose>
					<xsl:when test="Conductor/@Duplicate=1">
						<span class="textDuplicate">
							<xsl:value-of select="Conductor"/>
						</span>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="Conductor"/>
					</xsl:otherwise>
				</xsl:choose>
				<br/>
				<xsl:choose>
					<xsl:when test="Reader/@Duplicate=1">
						<span class="textDuplicate">
							<xsl:value-of select="Reader"/>
						</span>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="Reader"/>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</tr>
	</xsl:template>

	<!--Displays the song information-->
	<xsl:template match="SongOpen | SongMiddle | SongEnd">
		<td class="cellTime">
			<xsl:call-template name="DisplayTime"/>
		</td>
		<td class="cellTheme">
			<xsl:if test="self::SongMiddle">
				<xsl:attribute name="colspan">3</xsl:attribute>
				<xsl:attribute name="class"></xsl:attribute>
			</xsl:if>
			<span>
				<xsl:attribute name="class">
					<xsl:choose>
						<xsl:when test="self::SongOpen">bulletTFGW</xsl:when>
						<xsl:otherwise>bulletLAC</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
				<xsl:text>&#8226;</xsl:text>
			</span>
			<xsl:if test="self::SongOpen or (self::SongMiddle and . != '0') or (self::SongEnd and . != '0')">
				<span class="textSongLabel">
					<xsl:value-of select="//Labels/Song"/>
				</span>
				<span class="textSongNumber">
					<xsl:value-of select="."/>
				</span>
			</xsl:if>
			<span class="textSongTitle">
				<xsl:value-of select="@Title"/>
			</span>
		</td>
		<xsl:if test="self::SongOpen or self::SongEnd">
			<td class="cellPosition">
				<xsl:value-of select="//Labels/Prayer"/>
			</td>
		</xsl:if>
	</xsl:template>

	<!--Displays the comments-->
	<xsl:template name="Comments">
		<xsl:param name="bulletClass" />
		<tr>
			<xsl:apply-templates select="Time"/>
			<td class="cellTheme" colspan="2">
				<span class="{ $bulletClass }">&#8226;</span>
				<xsl:apply-templates select="Theme"/>
				<xsl:apply-templates select="Time" mode="Duration"/>
			</td>
			<xsl:call-template name="Chairman"/>
		</tr>
	</xsl:template>

	<xsl:template match="OpeningComments">
		<xsl:call-template name="Comments">
			<xsl:with-param name="bulletClass">bulletTFGW</xsl:with-param>
		</xsl:call-template>
	</xsl:template>

	<xsl:template match="ClosingComments">
		<xsl:call-template name="Comments">
			<xsl:with-param name="bulletClass">bulletLAC</xsl:with-param>
		</xsl:call-template>
	</xsl:template>


	<!--Displays the Prayer assignments-->
	<xsl:template match="PrayerOpen | PrayerClose" mode="WeekendMeeting">
		<tr>
			<td class="cellTime">
				<xsl:choose>
					<xsl:when test="self::PrayerOpen">
						<xsl:value-of select="../../SongInfo/SongOpen/@EndTime24"/>
					</xsl:when>
					<xsl:when test="self::PrayerClose">
						<xsl:value-of select="../../SongInfo/SongEnd/@EndTime24"/>
					</xsl:when>
				</xsl:choose>
			</td>
			<td class="cellWEEKENDText">
				<div class="floatRight">
					<xsl:value-of select="//Labels/Prayer"/>
				</div>
			</td>
			<td class="cellName">
				<xsl:choose>
					<xsl:when test="@Duplicate=1">
						<span class="textDuplicate">
							<xsl:value-of select="."/>
						</span>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="."/>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</tr>
	</xsl:template>	

	<!--Displays the Home Talk Speaker details-->
	<xsl:template match="HomeTalk">
		<tr>
			<xsl:apply-templates select="Time"/>
			<td class="cellWEEKENDText">
				<div class="floatRight">
					<xsl:value-of select="//Labels/PTS_Congregation"/>:
				</div>
				<xsl:choose>
					<xsl:when test="Symposium='1'">
						<span class="textPTSLabel">
							<xsl:value-of select="//Labels/PTS_Speakers"/>:
						</span>
						<xsl:text> </xsl:text>
						<span class="textPTSValue">
							<xsl:value-of select="Speaker"/>
						</span>
						<xsl:text> / </xsl:text>
						<span class="textPTSValue">
							<xsl:value-of select="Speaker2"/>
						</span>
					</xsl:when>
					<xsl:otherwise>
						<span class="textPTSLabel">
							<xsl:value-of select="//Labels/PTS_Speaker"/>:
						</span>
						<xsl:text> </xsl:text>
						<span class="textPTSValue">
							<xsl:value-of select="Speaker"/>
						</span>
					</xsl:otherwise>
				</xsl:choose>
			</td>
			<td class="cellName">
				<xsl:value-of select="Congregation"/>
			</td>
		</tr>
		<tr>
			<td class="cellWEEKENDText" colspan="3">
				<span class="textPTSLabel">
					<xsl:value-of select="//Labels/PTS_Theme"/>:
				</span>
				<xsl:text> </xsl:text>
				<span class="textPTSValue">
					<xsl:value-of select="Theme"/>
				</span>
			</td>
		</tr>
		<tr>
			<td colspan="2">
				<div class="floatRight">
					<xsl:value-of select="//Labels/PTS_Hospitality"/>:
				</div>
			</td>
			<td  class="cellName">
				<xsl:value-of select="../Assignments/Hospitality"/>
			</td>
		</tr>
	</xsl:template>

	<!--Displays the Away Talk Speaker and Congregation-->
	<xsl:template match="AwayTalk">
		<tr>
			<td class="cellWEEKENDText" colspan="3">
				<span class="textPTSLabel">
					<xsl:value-of select="//Labels/PTS_AwaySpeaker"/>:
				</span>
				<xsl:text> </xsl:text>
				<span class="textPTSValue">
					<xsl:value-of select="Speaker"/>
					<xsl:text> (</xsl:text>
					<xsl:value-of select="Congregation"/>
					<xsl:text>) </xsl:text>
					<xsl:value-of select="MeetingDate/@DayShort"/>
					<xsl:text> </xsl:text>
					<xsl:value-of select="MeetingDate"/>
					<xsl:text> @ </xsl:text>
					<xsl:value-of select="MeetingTime/@Time24"/>
				</span>
			</td>
		</tr>
	</xsl:template>

	<!--Displays the Watchtower Study, Conductor and Reader-->
	<xsl:template match="Assignments">
		<!--Heading-->
		<tr>
			<td style="padding-left: 1mm;" colspan="3">
				<div class="WTHeading">
					<xsl:value-of select="//Labels/PTS_WTStudy"/>
				</div>
			</td>
		</tr>
		<!--Watchtower Study Theme and Conductor-->
		<tr>
			<xsl:apply-templates select="WatchtowerStudy/Time"/>
			<td class="cellWEEKENDText">
				<span class="textPTSValue">
					<div class="floatRight">
						<xsl:value-of select="//Labels/PTS_WTConductor"/>:
					</div>
					<xsl:value-of select="WatchtowerStudy/Theme"/>
				</span>
			</td>
			<td class="cellName">
				<xsl:value-of select="Conductor"/>
			</td>
		</tr>
		<xsl:choose>
			<!-- This is not a Circuit Visit -->
			<xsl:when test="../../@CircuitVisit=0">
				<!-- Show the Reader -->
				<tr>
					<td class="cellWEEKENDText" colspan="2">
						<div class="floatRight">
							<xsl:value-of select="//Labels/PTS_WTReader"/>:
						</div>
					</td>
					<td class="cellName">
						<xsl:value-of select="Reader"/>
					</td>
				</tr>
			</xsl:when>
			<!--This is a Circuit Visit -->
			<xsl:when test="../../@CircuitVisit=1">
				<!-- Show the final Service Talk -->
				<tr>
					<td style="padding-left: 1mm;" colspan="3">
						<div class="ServiceTalkHeading">
							<xsl:value-of select="//Labels/PTS_ServiceTalk"/>
						</div>
					</td>
				</tr>
				<tr>
					<xsl:apply-templates select="ServiceTalk/Time"/>
					<td class="cellWEEKENDText">
						<span class="textPTSLabel">
							<xsl:value-of select="//Labels/PTS_Theme"/>:
						</span>
						<xsl:text> </xsl:text>
						<span class="textPTSValue">
							<xsl:value-of select="ServiceTalk/Theme"/>
						</span>
					</td>
					<td class="cellName">
						<xsl:value-of select="../preceding-sibling::*[1]/CircuitVisit/LACItem/Name"/>
					</td>
				</tr>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="SongMiddle | SongEnd" mode="SpecialEvent">
		<tr>
			<td class="cellTime">
				<xsl:call-template name="DisplayTime"/>
			</td>
			<td style="padding-left: 3mm">
				<div class="floatRight">
					<xsl:value-of select="//Labels/Prayer"/>
				</div>
				<span class="textSongLabel">
					<xsl:value-of select="//Labels/Song"/>
				</span>
				<span class="textSongNumber">
					<xsl:value-of select="."/>
				</span>
				<span class="textSongTitle">
					<xsl:value-of select="@Title"/>
				</span>
			</td>
			<td class="cellName">
				<xsl:choose>
					<!-- Middle song -->
					<xsl:when test="self::SongMiddle">
						<xsl:value-of select="../../Assignments/PrayerOpen"/>
					</xsl:when>
					<!--  Closing song -->
					<xsl:otherwise>
						<xsl:value-of select="../../Assignments/PrayerClose"/>
					</xsl:otherwise>
				</xsl:choose>
			</td>
		</tr>
	</xsl:template>

</xsl:stylesheet>